@@ -8,8 +8,8 @@
 #include <iostream.h>
 #include <fstream.h>
 #include <time.h>
-#include <string.h>
 #include <stdlib.h>
+#include <string.h>
 #include "trans.h"
 
 void credit( char amt[], char com[] )
@@ -26,9 +26,9 @@ void credit( char amt[], char com[] )
 
 	cout << "Credit: " << t << endl;
 
-	time_t timer = time( NULL );
-	fout << "#" << asctime( localtime( &timer ) );
-	fout << "#" << com << endl;
+	fout << "#";
+	dateOut ( fout );
+	fout << endl << "#" << com << endl;
 
 	fout << t;
 
