@@ -17,9 +17,7 @@ void debit( char amt[], char com[] )
 	char *file;
 	file = getenv( "HOME" );
 
-	strcat( file, "/" );
-	strcat( file, ".brinance" );
-	strcat( file, "/account" );
+	strcat( file, "/.brinance/account" );
 
 	ofstream fout;
 	fout.open( file, ios::app );
@@ -29,9 +27,9 @@ void debit( char amt[], char com[] )
 
 	cout << "Debit: " << t << endl;
 
-	time_t timer = time( NULL );
-	fout << "#" << asctime( localtime( &timer ) );
-	fout << "#" << com << endl;
+	fout << "#";
+	dateOut ( fout );
+	fout << endl << "#" << com << endl;
 
 	fout << t;
 
