@@ -57,9 +57,12 @@ trans::trans( char amt[] )
 		if (neg) {
 			total *= -1;
 		}
-		if (pastDec == 0) {
+		if (pastDec == 0 || pastDec == 1) {
 			total *= 100;
 		}
+		if (pastDec == 2) {
+			total *= 10;
+		}
 		this->amt = total;
 	}
 	else {
