@@ -5,6 +5,9 @@
 
 */
 
+#include <time.h>
+#include <iostream.h>
+
 /*
 	bool toInt(char c, int& i)
 
@@ -14,3 +17,5 @@
 */
 bool toInt( char c, int& i );
 
+void dateOut( ostream &out );
+
